Chert - Colophon

# Colophon

Most blogs, including this one, are reverse-chronologically ordered, causing the first post to appear last in the archive. This convention makes a colophon the King's Pawn Game of web authorship; there's no better place to showcase certain implementation details than the first post of a blog.

This site is generated with Chert1, an open-source static site generator built with Python, Markdown2, ashes, pygments, and YAML. Chert is named for a very common fine-grained sedimentary rock, often referred to as flint, that has been of critical use to firestarters through the ages.

1. English pronunciation rhymes with dirt, maintainer/Farsi pronunciation: chair with a t at the end. ↩

2. Enhanced Markdown, including support for footnotes, definition lists, and tables of contents. ↩

October 31st, 2014 #meta #code